@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Parser;
-$Test::BDD::Cucumber::Parser::VERSION = '0.28';
+$Test::BDD::Cucumber::Parser::VERSION = '0.29';
 =head1 NAME
 
 Test::BDD::Cucumber::Parser - Parse Feature files
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 DESCRIPTION
 
@@ -65,7 +65,7 @@ sub parse_file {
             {
                 content =>
                   scalar( read_file( $string, { binmode => ':utf8' } ) ),
-                filename => $string
+                filename => '' . $string
             }
         ),
         $tag_scheme
